@@ -130,6 +130,10 @@ FILE_OPTIONS = {
         cfg.StrOpt('redis_server',
                    default='localhost:6379',
                    help='Redis server in the format of "host:port"'),
+        cfg.IntOpt('redis_db',
+                   default=0,
+                   min=0,
+                   help='Database id in Redis server'),
         cfg.StrOpt('redis_username',
                    help='the user name for redis'),
         cfg.StrOpt('redis_password',
